@@ -1,9 +1,5 @@
-# Copyright (C) 2009-2012 AG Projects. See LICENSE for details.
-#
 
-"""Implements a notification system"""
-
-__all__ = ['Any', 'UnknownSender', 'IObserver', 'NotificationData', 'Notification', 'NotificationCenter', 'ObserverWeakrefProxy']
+"""A notification system"""
 
 import weakref
 from collections import deque
@@ -18,23 +14,24 @@ from application.python.types import Singleton, MarkerType
 from application.python.weakref import weakobjectmap
 
 
-## Special objects
+__all__ = 'Any', 'UnknownSender', 'IObserver', 'NotificationData', 'Notification', 'NotificationCenter', 'ObserverWeakrefProxy'
+
 
 class Any(object):
     """Any sender or notification name"""
     __metaclass__ = MarkerType
 
+
 class UnknownSender(object):
     """A special sender used for anonymous notifications"""
     __metaclass__ = MarkerType
 
 
-## Notification Observer
-
 class IObserver(Interface):
     """Interface describing a Notification Observer"""
 
-    def handle_notification(notification):
+    # noinspection PyMethodMayBeStatic
+    def handle_notification(self, notification):
         """Function used to handle a posted Notification"""
 
 
@@ -52,7 +49,7 @@ class ObserverWeakrefProxy(object):
 
     def __new__(cls, observer):
         if not IObserver.providedBy(observer):
-            raise TypeError("observer must implement the IObserver interface")
+            raise TypeError('observer must implement the IObserver interface')
         with cls.lock:
             if observer in cls.observer_map:
                 return cls.observer_map[observer]
@@ -61,6 +58,7 @@ class ObserverWeakrefProxy(object):
             cls.observer_map[observer] = instance
             return instance
 
+    # noinspection PyUnusedLocal
     def cleanup(self, ref):
         # remove all observer's remaining registrations (the ones that the observer didn't remove itself)
         for notification_center in NotificationCenter.__instances__.itervalues():
@@ -72,8 +70,6 @@ class ObserverWeakrefProxy(object):
             observer.handle_notification(notification)
 
 
-## Notification
-
 class NotificationData(object):
     """Object containing the notification data"""
 
@@ -89,7 +85,7 @@ class Notification(object):
 
     def __init__(self, name, sender=UnknownSender, data=NotificationData()):
         if name is Any or sender is Any:
-            raise ValueError("name and/or sender must not be the special object Any")
+            raise ValueError('name and/or sender must not be the special object Any')
         self.name = name
         self.sender = sender
         self.data = data
@@ -107,8 +103,6 @@ class Notification(object):
         return '%s(%r, %r, %r)' % (self.__class__.__name__, self.name, self.sender, self.data)
 
 
-## Notification Center
-
 class NotificationCenter(object):
     """
     A NotificationCenter allows observers to subscribe to receive notifications
@@ -141,7 +135,7 @@ class NotificationCenter(object):
         UnknownSender, the observer will only receive anonymous notifications.
         """
         if not IObserver.providedBy(observer):
-            raise TypeError("observer must implement the IObserver interface")
+            raise TypeError('observer must implement the IObserver interface')
         with self.lock:
             self.observers.setdefault((name, sender), set()).add(observer)
 
@@ -160,7 +154,7 @@ class NotificationCenter(object):
                 observer_set = self.observers[(name, sender)]
                 observer_set.remove(observer)
             except KeyError:
-                raise KeyError("observer %r not registered for %r events from %r" % (observer, name, sender))
+                raise KeyError('observer %r not registered for %r events from %r' % (observer, name, sender))
             if not observer_set:
                 del self.observers[(name, sender)]
 
@@ -200,7 +194,8 @@ class NotificationCenter(object):
         notification.center = self
         queue = self.queue
         queue.append(notification)
-        if len(queue) > 1: # This is true if we post a notification from inside a notification handler
+        # noinspection PyTypeChecker
+        if len(queue) > 1:  # This is true if we post a notification from inside a notification handler
             return
 
         empty_set = set()
@@ -215,8 +210,5 @@ class NotificationCenter(object):
                 try:
                     observer.handle_notification(notification)
                 except Exception:
-                    log.error("Exception occured in observer %r while handling notification %r" % (observer, notification.name))
-                    log.err()
+                    log.exception('Unhandled exception in notification observer %r while handling notification %r' % (observer, notification.name))
             queue.popleft()
-
-
